/****************************************************************************
**
** Copyright (C) 2019 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

import QtQuick 2.0
import QtQuick3D 1.15

IconGizmo {
    id: lightGizmo

    property Model lightModel: null
    property color overlayColor: targetNode ? targetNode.color : "transparent"

    iconSource: targetNode
                ? targetNode instanceof DirectionalLight
                  ? "image://IconGizmoImageProvider/directional_light_gradient.png:" + overlayColor
                  : targetNode instanceof AreaLight
                    ? "image://IconGizmoImageProvider/area_light_gradient.png:" + overlayColor
                    : targetNode instanceof PointLight
                      ? "image://IconGizmoImageProvider/point_light_gradient.png:" + overlayColor
                      : "image://IconGizmoImageProvider/spot_light_gradient.png:" + overlayColor
                : "image://IconGizmoImageProvider/point_light_gradient.png:" + overlayColor

    function connectModel(model)
    {
        lightModel = model;

        model.selected = selected;
        model.selected = Qt.binding(function() {return selected;});

        model.scene = scene;
        model.scene = Qt.binding(function() {return scene;});

        model.targetNode = targetNode;
        model.targetNode = Qt.binding(function() {return targetNode;});

        model.color = lightGizmo.overlayColor;
        model.color = Qt.binding(function() {return lightGizmo.overlayColor;});

        model.visible = visible;
        model.visible = Qt.binding(function() {return visible;});
    }

    onActiveSceneChanged: {
        if (lightModel && activeScene == scene)
            lightModel.updateGeometry();
    }
}
